@@ -20,6 +20,7 @@ from numpyro.distributions.continuous import (
     Cauchy,
     Chi2,
     Dirichlet,
+    EulerMaruyama,
     Exponential,
     Gamma,
     GaussianRandomWalk,
@@ -32,7 +33,9 @@ from numpyro.distributions.continuous import (
     LKJCholesky,
     Logistic,
     LogNormal,
+    LogUniform,
     LowRankMultivariateNormal,
+    MatrixNormal,
     MultivariateNormal,
     MultivariateStudentT,
     Normal,
@@ -44,6 +47,7 @@ from numpyro.distributions.continuous import (
     Uniform,
     Weibull,
 )
+from numpyro.distributions.copula import GaussianCopula, GaussianCopulaBeta
 from numpyro.distributions.directional import (
     ProjectedNormal,
     SineBivariateVonMises,
@@ -124,11 +128,14 @@ __all__ = [
     "DirichletMultinomial",
     "DiscreteUniform",
     "Distribution",
+    "EulerMaruyama",
     "Exponential",
     "ExpandedDistribution",
     "FoldedDistribution",
     "Gamma",
     "GammaPoisson",
+    "GaussianCopula",
+    "GaussianCopulaBeta",
     "GaussianRandomWalk",
     "Geometric",
     "GeometricLogits",
@@ -146,6 +153,8 @@ __all__ = [
     "LeftTruncatedDistribution",
     "Logistic",
     "LogNormal",
+    "LogUniform",
+    "MatrixNormal",
     "MaskedDistribution",
     "Mixture",
     "MixtureSameFamily",
