@@ -27,14 +27,14 @@
 
 import numpy as np
 
-from jax import lax
+from jax import lax, vmap
 from jax.experimental.sparse import BCOO
+from jax.lax import scan
 import jax.nn as nn
 import jax.numpy as jnp
 import jax.random as random
 from jax.scipy.linalg import cho_solve, solve_triangular
 from jax.scipy.special import (
-    betainc,
     betaln,
     expit,
     gammainc,
@@ -58,7 +58,10 @@ from numpyro.distributions.transforms import (
     SigmoidTransform,
 )
 from numpyro.distributions.util import (
+    betainc,
+    betaincinv,
     cholesky_of_inverse,
+    gammaincinv,
     is_prng_key,
     lazy_property,
     matrix_to_tril_vec,
@@ -187,6 +190,9 @@ class Beta(Distribution):
     def cdf(self, value):
         return betainc(self.concentration1, self.concentration0, value)
 
+    def icdf(self, q):
+        return betaincinv(self.concentration1, self.concentration0, q)
+
 
 class Cauchy(Distribution):
     arg_constraints = {"loc": constraints.real, "scale": constraints.positive}
@@ -285,6 +291,133 @@ class Dirichlet(Distribution):
         return batch_shape, event_shape
 
 
+class EulerMaruyama(Distribution):
+    """
+    Euler–Maruyama method is a method for the approximate numerical solution
+    of a stochastic differential equation (SDE)
+
+    :param ndarray t: discretized time
+    :param callable sde_fn: function returning the drift and diffusion coefficients of SDE
+    :param Distribution init_dist: Distribution for initial values.
+
+    **References**
+
+    [1] https://en.wikipedia.org/wiki/Euler-Maruyama_method
+    """
+
+    arg_constraints = {"t": constraints.ordered_vector}
+
+    def __init__(self, t, sde_fn, init_dist, *, validate_args=None):
+        self.t = t
+        self.sde_fn = sde_fn
+        self.init_dist = init_dist
+
+        if not isinstance(init_dist, Distribution):
+            raise TypeError("Init distribution is expected to be Distribution class.")
+
+        batch_shape_t = jnp.shape(t)[:-1]
+        batch_shape = lax.broadcast_shapes(batch_shape_t, init_dist.batch_shape)
+        event_shape = (jnp.shape(t)[-1],) + init_dist.event_shape
+
+        super(EulerMaruyama, self).__init__(
+            batch_shape, event_shape, validate_args=validate_args
+        )
+
+    @constraints.dependent_property(is_discrete=False)
+    def support(self):
+        return constraints.independent(constraints.real, self.event_dim)
+
+    def sample(self, key, sample_shape=()):
+        assert is_prng_key(key)
+        batch_shape = sample_shape + self.batch_shape
+
+        def step(y_curr, xs):
+            noise_curr, t_curr, dt_curr = xs
+            f, g = self.sde_fn(y_curr, t_curr)
+            mu = y_curr + dt_curr * f
+            sigma = jnp.sqrt(dt_curr) * g
+            y_next = mu + sigma * noise_curr
+            return y_next, y_next
+
+        rng_noise, rng_init = random.split(key)
+        noises = random.normal(
+            rng_noise,
+            shape=batch_shape + (self.event_shape[0] - 1,) + self.event_shape[1:],
+        )
+        inits = self.init_dist.expand(batch_shape).sample(rng_init)
+
+        def scan_fn(init, noise, tm1, dt):
+            return scan(step, init, (noise, tm1, dt))
+
+        batch_dim = len(batch_shape)
+        if batch_dim:
+            inits = inits.reshape((-1,) + inits.shape[batch_dim:])
+            noises = noises.reshape((-1,) + noises.shape[batch_dim:])
+            t = jnp.broadcast_to(self.t, batch_shape + (self.event_shape[0],))
+            t = t.reshape((-1,) + t.shape[batch_dim:])
+            dt = jnp.diff(t, axis=-1)
+            _, sde_out = vmap(scan_fn)(inits, noises, t[..., :-1], dt)
+            sde_out = jnp.concatenate([inits[:, None], sde_out], axis=1)
+            sde_out = jnp.reshape(sde_out, batch_shape + self.event_shape)
+        else:
+            dt = jnp.diff(self.t, axis=-1)
+            _, sde_out = scan_fn(inits, noises, self.t[:-1], dt)
+            sde_out = jnp.concatenate([inits[None], sde_out], axis=0)
+
+        return sde_out
+
+    @validate_sample
+    def log_prob(self, value):
+        sample_shape = lax.broadcast_shapes(
+            value.shape[: -self.event_dim], self.batch_shape
+        )
+        value = jnp.broadcast_to(value, sample_shape + self.event_shape)
+
+        if sample_shape:
+            reshaped_value = value.reshape((-1,) + self.event_shape)
+            xtm1, xt = reshaped_value[:, :-1], reshaped_value[:, 1:]
+            value0 = reshaped_value[:, 0]
+            t = jnp.broadcast_to(self.t, sample_shape + (self.event_shape[0],))
+            t = t.reshape((-1,) + (self.event_shape[0],))
+
+            f, g = vmap(vmap(self.sde_fn))(xtm1, t[:, :-1])
+
+            f = f.reshape(sample_shape + f.shape[1:])
+            g = g.reshape(sample_shape + g.shape[1:])
+            xtm1 = xtm1.reshape(sample_shape + xtm1.shape[1:])
+            xt = xt.reshape(sample_shape + xt.shape[1:])
+            value0 = value0.reshape(sample_shape + value0.shape[1:])
+
+        else:
+            xtm1, xt = value[:-1], value[1:]
+            value0 = value[0]
+
+            f, g = vmap(self.sde_fn)(xtm1, self.t[:-1])
+
+        # add missing event dimensions
+        batch_dim = len(sample_shape)
+        f = f.reshape(
+            f.shape[: batch_dim + 1]
+            + (1,) * (xt.ndim - f.ndim)
+            + f.shape[batch_dim + 1 :]
+        )
+        g = g.reshape(
+            g.shape[: batch_dim + 1]
+            + (1,) * (xt.ndim - g.ndim)
+            + g.shape[batch_dim + 1 :]
+        )
+
+        dt = jnp.diff(self.t, axis=-1)
+        dt = dt.reshape(dt.shape + (1,) * (self.event_dim - 1))
+        mu = xtm1 + dt * f
+        sigma = jnp.sqrt(dt) * g
+
+        sde_log_prob = Normal(mu, sigma).to_event(self.event_dim).log_prob(xt)
+        init_log_prob = self.init_dist.log_prob(value0)
+
+        return sde_log_prob + init_log_prob
+
+
 class Exponential(Distribution):
     reparametrized_params = ["rate"]
     arg_constraints = {"rate": constraints.positive}
@@ -363,6 +496,9 @@ class Gamma(Distribution):
     def cdf(self, x):
         return gammainc(self.concentration, self.rate * x)
 
+    def icdf(self, q):
+        return gammaincinv(self.concentration, q) / self.rate
+
 
 class Chi2(Gamma):
     arg_constraints = {"df": constraints.positive}
@@ -1033,6 +1169,172 @@ class Logistic(Distribution):
         return self.loc + self.scale * logit(q)
 
 
+class LogUniform(TransformedDistribution):
+    arg_constraints = {"low": constraints.positive, "high": constraints.positive}
+    reparametrized_params = ["low", "high"]
+
+    def __init__(self, low, high, *, validate_args=None):
+        base_dist = Uniform(jnp.log(low), jnp.log(high))
+        self.low, self.high = promote_shapes(low, high)
+        self._support = constraints.interval(self.low, self.high)
+        super(LogUniform, self).__init__(
+            base_dist, ExpTransform(), validate_args=validate_args
+        )
+
+    @constraints.dependent_property(is_discrete=False, event_dim=0)
+    def support(self):
+        return self._support
+
+    @property
+    def mean(self):
+        return (self.high - self.low) / jnp.log(self.high / self.low)
+
+    @property
+    def variance(self):
+        return (
+            0.5 * (self.high**2 - self.low**2) / jnp.log(self.high / self.low)
+            - self.mean**2
+        )
+
+    def tree_flatten(self):
+        return super(TransformedDistribution, self).tree_flatten()
+
+    def cdf(self, x):
+        return self.base_dist.cdf(jnp.log(x))
+
+
+def _batch_solve_triangular(A, B):
+    """
+    Extende solve_triangular for the case that B.ndim > A.ndim.
+    This is achived by first flattening the leading B.ndim - A.ndim dimensions of B and then
+    moving the first dimension to the end.
+
+
+    :param jnp.ndarray (...,M,M) A: An array with lower triangular structure in the last two dimensions.
+    :param jnp.ndarray (...,M,N) B: Right-hand side matrix in A x = B.
+
+    :return: Solution of A x = B.
+    """
+    event_shape = B.shape[-2:]
+    batch_shape = lax.broadcast_shapes(A.shape[:-2], B.shape[-A.ndim : -2])
+    sample_shape = B.shape[: -A.ndim]
+    n, p = event_shape
+
+    A = jnp.broadcast_to(A, batch_shape + A.shape[-2:])
+    B = jnp.broadcast_to(B, sample_shape + batch_shape + event_shape)
+
+    B_flat = jnp.moveaxis(B.reshape((-1,) + batch_shape + event_shape), 0, -2).reshape(
+        batch_shape + (n,) + (-1,)
+    )
+
+    X_flat = solve_triangular(A, B_flat, lower=True)
+
+    sample_shape_dim = len(sample_shape)
+    src_axes = tuple([-2 - i for i in range(sample_shape_dim)])
+    src_axes = src_axes[::-1]
+    dest_axes = tuple([i for i in range(sample_shape_dim)])
+
+    X = jnp.moveaxis(
+        X_flat.reshape(batch_shape + (n,) + sample_shape + (p,)),
+        src_axes,
+        dest_axes,
+    )
+    return X
+
+
+class MatrixNormal(Distribution):
+    """
+    Matrix variate normal distribution as described in [1] but with a lower_triangular parametrization,
+    i.e. :math:`U=scale_tril_row @ scale_tril_row^{T}` and :math:`V=scale_tril_column @ scale_tril_column^{T}`.
+    The distribution is related to the multivariate normal distribution in the following way.
+    If :math:`X ~ MN(loc,U,V)` then :math:`vec(X) ~ MVN(vec(loc), kron(V,U) )`.
+
+    :param array_like loc: Location of the distribution.
+    :param array_like scale_tril_row: Lower cholesky of rows correlation matrix.
+    :param array_like scale_tril_column: Lower cholesky of columns correlation matrix.
+
+    **References**
+
+    [1] https://en.wikipedia.org/wiki/Matrix_normal_distribution
+    """
+
+    arg_constraints = {
+        "loc": constraints.real_vector,
+        "scale_tril_row": constraints.lower_cholesky,
+        "scale_tril_column": constraints.lower_cholesky,
+    }
+    support = constraints.real_matrix
+    reparametrized_params = [
+        "loc",
+        "scale_tril_row",
+        "scale_tril_column",
+    ]
+
+    def __init__(self, loc, scale_tril_row, scale_tril_column, validate_args=None):
+        event_shape = loc.shape[-2:]
+        batch_shape = lax.broadcast_shapes(
+            jnp.shape(loc)[:-2],
+            jnp.shape(scale_tril_row)[:-2],
+            jnp.shape(scale_tril_column)[:-2],
+        )
+        (self.loc,) = promote_shapes(loc, shape=batch_shape + loc.shape[-2:])
+        (self.scale_tril_row,) = promote_shapes(
+            scale_tril_row, shape=batch_shape + scale_tril_row.shape[-2:]
+        )
+        (self.scale_tril_column,) = promote_shapes(
+            scale_tril_column, shape=batch_shape + scale_tril_column.shape[-2:]
+        )
+        super(MatrixNormal, self).__init__(
+            batch_shape=batch_shape,
+            event_shape=event_shape,
+            validate_args=validate_args,
+        )
+
+    @property
+    def mean(self):
+        return jnp.broadcast_to(self.loc, self.shape())
+
+    def sample(self, key, sample_shape=()):
+
+        eps = random.normal(
+            key, shape=sample_shape + self.batch_shape + self.event_shape
+        )
+        samples = self.loc + self.scale_tril_row @ eps @ jnp.swapaxes(
+            self.scale_tril_column, -2, -1
+        )
+
+        return samples
+
+    @validate_sample
+    def log_prob(self, values):
+
+        n, p = self.event_shape
+
+        row_log_det = jnp.log(
+            jnp.diagonal(self.scale_tril_row, axis1=-2, axis2=-1)
+        ).sum(-1)
+        col_log_det = jnp.log(
+            jnp.diagonal(self.scale_tril_column, axis1=-2, axis2=-1)
+        ).sum(-1)
+        log_det_term = (
+            p * row_log_det + n * col_log_det + 0.5 * n * p * jnp.log(2 * jnp.pi)
+        )
+
+        # compute the trace term
+        diff = values - self.loc
+        diff_row_solve = _batch_solve_triangular(A=self.scale_tril_row, B=diff)
+        diff_col_solve = _batch_solve_triangular(
+            A=self.scale_tril_column, B=jnp.swapaxes(diff_row_solve, -2, -1)
+        )
+        batched_trace_term = jnp.square(
+            diff_col_solve.reshape(diff_col_solve.shape[:-2] + (-1,))
+        ).sum(-1)
+
+        log_prob = -0.5 * batched_trace_term - log_det_term
+
+        return log_prob
+
+
 def _batch_mahalanobis(bL, bx):
     if bL.shape[:-1] == bx.shape:
         # no need to use the below optimization procedure
@@ -1245,7 +1547,7 @@ class CAR(Distribution):
         adj_matrix,
         *,
         is_sparse=False,
-        validate_args=None
+        validate_args=None,
     ):
         if jnp.ndim(loc) == 0:
             (loc,) = promote_shapes(loc, shape=(1,))
@@ -1914,19 +2216,20 @@ class StudentT(Distribution):
         scaled = (value - self.loc) / self.scale
         scaled_squared = scaled * scaled
         beta_value = self.df / (self.df + scaled_squared)
+
         # when scaled < 0, returns 0.5 * Beta(df/2, 0.5).cdf(beta_value)
         # when scaled > 0, returns 1 - 0.5 * Beta(df/2, 0.5).cdf(beta_value)
-        scaled_sign_half = 0.5 * jnp.sign(scaled)
-        return (
-            0.5
-            + scaled_sign_half
-            - 0.5 * jnp.sign(scaled) * betainc(0.5 * self.df, 0.5, beta_value)
+        return 0.5 * (
+            1
+            + jnp.sign(scaled)
+            - jnp.sign(scaled) * betainc(0.5 * self.df, 0.5, beta_value)
         )
 
     def icdf(self, q):
-        # scipy.special.betaincinv is not avaiable yet in JAX
-        # upstream issue: https://github.com/google/jax/issues/2399
-        raise NotImplementedError
+        beta_value = betaincinv(0.5 * self.df, 0.5, 1 - jnp.abs(1 - 2 * q))
+        scaled_squared = self.df * (1 / beta_value - 1)
+        scaled = jnp.sign(q - 0.5) * jnp.sqrt(scaled_squared)
+        return scaled * self.scale + self.loc
 
 
 class Uniform(Distribution):
@@ -2075,7 +2378,7 @@ class AsymmetricLaplaceQuantile(Distribution):
     the distribution.
 
     The `scale` parameter is also interpreted slightly differently than in
-    AsymmetricLaplce. When `loc=0` and `scale=1`, AsymmetricLaplace(0,1,1)
+    AsymmetricLaplace. When `loc=0` and `scale=1`, AsymmetricLaplace(0,1,1)
     is equivalent to Laplace(0,1), while AsymmetricLaplaceQuantile(0,1,0.5) is
     equivalent to Laplace(0,2).
     """
