@@ -325,7 +325,7 @@ class SineBivariateVonMises(Distribution):
     :param np.ndarray phi_concentration: concentration of first angle
     :param np.ndarray psi_concentration: concentration of second angle
     :param np.ndarray correlation: correlation between the two angles
-    :param np.ndarray weighted_correlation: set correlation to weigthed_corr * sqrt(phi_conc*psi_conc)
+    :param np.ndarray weighted_correlation: set correlation to weighted_corr * sqrt(phi_conc*psi_conc)
         to avoid bimodality (see note). The `weighted_correlation` should be in [0,1].
     """
 
@@ -352,9 +352,8 @@ class SineBivariateVonMises(Distribution):
         assert (correlation is None) != (weighted_correlation is None)
 
         if weighted_correlation is not None:
-            correlation = (
-                weighted_correlation * jnp.sqrt(phi_concentration * psi_concentration)
-                + 1e-8
+            correlation = weighted_correlation * jnp.sqrt(
+                phi_concentration * psi_concentration
             )
 
         batch_shape = lax.broadcast_shapes(
@@ -389,7 +388,7 @@ class SineBivariateVonMises(Distribution):
 
     @lazy_property
     def norm_const(self):
-        corr = jnp.reshape(self.correlation, (1, -1)) + 1e-8
+        corr = jnp.reshape(self.correlation, (1, -1))
         conc = jnp.stack(
             (self.phi_concentration, self.psi_concentration), axis=-1
         ).reshape(-1, 2)
@@ -398,14 +397,12 @@ class SineBivariateVonMises(Distribution):
         den = special.gammaln(m + 1.0)
         lbinoms = num - 2 * den
 
-        fs = (
-            lbinoms.reshape(-1, 1)
-            + 2 * m * jnp.log(corr)
-            - m * jnp.log(4 * jnp.prod(conc, axis=-1))
+        fs = lbinoms.reshape(-1, 1) + m * (
+            jnp.log(jnp.clip(corr**2, a_min=jnp.finfo(jnp.result_type(float)).tiny))
+            - jnp.log(4 * jnp.prod(conc, axis=-1))
         )
         fs += log_I1(49, conc, terms=51).sum(-1)
-        mfs = fs.max()
-        norm_const = 2 * jnp.log(jnp.array(2 * pi)) + mfs + logsumexp(fs - mfs, 0)
+        norm_const = 2 * jnp.log(jnp.array(2 * pi)) + logsumexp(fs, 0)
         return norm_const.reshape(jnp.shape(self.phi_loc))
 
     @validate_sample
