@@ -142,15 +142,13 @@ class Distribution(metaclass=DistributionMeta):
 
     def tree_flatten(self):
         return (
-            tuple(
-                getattr(self, param) for param in sorted(self.arg_constraints.keys())
-            ),
+            tuple(getattr(self, param) for param in self.arg_constraints.keys()),
             None,
         )
 
     @classmethod
     def tree_unflatten(cls, aux_data, params):
-        return cls(**dict(zip(sorted(cls.arg_constraints.keys()), params)))
+        return cls(**dict(zip(cls.arg_constraints.keys(), params)))
 
     @staticmethod
     def set_default_validate_args(value):
