@@ -458,7 +458,9 @@ class ExpTransform(Transform):
 
     @property
     def codomain(self):
-        if self.domain is constraints.real:
+        if self.domain is constraints.ordered_vector:
+            return constraints.positive_ordered_vector
+        elif self.domain is constraints.real:
             return constraints.positive
         elif isinstance(self.domain, constraints.greater_than):
             return constraints.greater_than(self.__call__(self.domain.lower_bound))
@@ -609,7 +611,7 @@ class LowerCholeskyAffine(Transform):
        >>> scale_tril = jnp.array([[0.3, 0.0], [1.0, 0.5]])
        >>> affine = LowerCholeskyAffine(loc=loc, scale_tril=scale_tril)
        >>> affine(base)
-       DeviceArray([0.3, 1.5], dtype=float32)
+       Array([0.3, 1.5], dtype=float32)
     """
     domain = constraints.real_vector
     codomain = constraints.real_vector
@@ -1063,10 +1065,13 @@ def _transform_to_corr_matrix(constraint):
     )
 
 
+@biject_to.register(type(constraints.positive))
+def _transform_to_positive(constraint):
+    return ExpTransform()
+
+
 @biject_to.register(constraints.greater_than)
 def _transform_to_greater_than(constraint):
-    if constraint is constraints.positive:
-        return ExpTransform()
     return ComposeTransform(
         [
             ExpTransform(),
@@ -1085,6 +1090,8 @@ def _transform_to_less_than(constraint):
     )
 
 
+@biject_to.register(type(constraints.real_matrix))
+@biject_to.register(type(constraints.real_vector))
 @biject_to.register(constraints.independent)
 def _biject_to_independent(constraint):
     return IndependentTransform(
@@ -1092,11 +1099,15 @@ def _biject_to_independent(constraint):
     )
 
 
+@biject_to.register(type(constraints.unit_interval))
+def _transform_to_unit_interval(constraint):
+    return SigmoidTransform()
+
+
+@biject_to.register(type(constraints.circular))
 @biject_to.register(constraints.open_interval)
 @biject_to.register(constraints.interval)
 def _transform_to_interval(constraint):
-    if constraint is constraints.unit_interval:
-        return SigmoidTransform()
     scale = constraint.upper_bound - constraint.lower_bound
     return ComposeTransform(
         [
