@@ -414,6 +414,47 @@ def clamp_probs(probs):
     return jnp.clip(probs, a_min=finfo.tiny, a_max=1.0 - finfo.eps)
 
 
+def betainc(a, b, x):
+    try:
+        from tensorflow_probability.substrates.jax.math import betainc as betainc_fn
+    except ImportError:
+        from jax.scipy.special import betainc as betainc_fn
+
+    dtype = jnp.result_type(float)
+    return betainc_fn(
+        jnp.array(a, dtype=dtype),
+        jnp.array(b, dtype=dtype),
+        jnp.array(x, dtype=dtype),
+    )
+
+
+def betaincinv(a, b, y):
+    try:
+        from tensorflow_probability.substrates.jax.math import special as tfp_special
+    except ImportError as e:
+        raise ImportError(
+            "Please install `tensorflow_probability>=0.18` for betaincinv."
+        ) from e
+
+    dtype = jnp.result_type(float)
+    return tfp_special.betaincinv(
+        jnp.array(a, dtype=dtype),
+        jnp.array(b, dtype=dtype),
+        jnp.array(y, dtype=dtype),
+    )
+
+
+def gammaincinv(a, y):
+    try:
+        from tensorflow_probability.substrates.jax import math as tfp_math
+
+        return tfp_math.igammainv(jnp.array(a), jnp.array(y))
+    except ImportError as e:
+        raise ImportError(
+            "Please install `tensorflow_probability>=0.18` for gammaincinv."
+        ) from e
+
+
 def is_identically_zero(x):
     """
     Check if argument is exactly the number zero. True for the number zero;
