@@ -137,10 +137,10 @@ class trace(Messenger):
                      {'args': (),
                       'fn': <numpyro.distributions.continuous.Normal object at 0x7f9e689b1eb8>,
                       'is_observed': False,
-                      'kwargs': {'rng_key': DeviceArray([0, 0], dtype=uint32)},
+                      'kwargs': {'rng_key': Array([0, 0], dtype=uint32)},
                       'name': 'a',
                       'type': 'sample',
-                      'value': DeviceArray(-0.20584235, dtype=float32)})])
+                      'value': Array(-0.20584235, dtype=float32)})])
     """
 
     def __enter__(self):
@@ -573,7 +573,7 @@ class reparam(Messenger):
                 msg["type"] = "deterministic"
                 msg["value"] = value
                 for key in list(msg.keys()):
-                    if key not in ("type", "name", "value"):
+                    if key not in ("type", "name", "value", "cond_indep_stack"):
                         del msg[key]
                 return
 
@@ -609,6 +609,13 @@ class scale(Messenger):
         msg["scale"] = (
             self.scale if msg.get("scale") is None else self.scale * msg["scale"]
         )
+        plate_to_scale = msg.setdefault("plate_to_scale", {})
+        scale = (
+            self.scale
+            if plate_to_scale.get(None) is None
+            else self.scale * plate_to_scale[None]
+        )
+        plate_to_scale[None] = scale
 
 
 class scope(Messenger):
