@@ -63,6 +63,8 @@ __all__ = [
     "AutoBNAFNormal",
     "AutoIAFNormal",
     "AutoDelta",
+    "AutoSemiDAIS",
+    "AutoSurrogateLikelihoodDAIS",
 ]
 
 
@@ -673,7 +675,7 @@ class AutoDAIS(AutoContinuous):
     and Annealed Importance Sampling. The same algorithm is called Uncorrected
     Hamiltonian Annealing in [1].
 
-    Note that AutoDAIS cannot be used in conjuction with data subsampling.
+    Note that AutoDAIS cannot be used in conjunction with data subsampling.
 
     **Reference:**
 
@@ -753,7 +755,7 @@ class AutoDAIS(AutoContinuous):
                 and site["args"][0] > site["args"][1]
             ):
                 raise NotImplementedError(
-                    "AutoDAIS cannot be used in conjuction with data subsampling."
+                    "AutoDAIS cannot be used in conjunction with data subsampling."
                 )
 
     def _get_posterior(self):
@@ -864,6 +866,579 @@ class AutoDAIS(AutoContinuous):
             return _single_sample(rng_key)
 
 
+class AutoSurrogateLikelihoodDAIS(AutoDAIS):
+    """
+    This implementation of :class:`AutoSurrogateLikelihoodDAIS` provides a
+    mini-batchable family of variational distributions as described in [1].
+    It combines a user-provided surrogate likelihood with Differentiable Annealed
+    Importance Sampling (DAIS) [2, 3]. It is not applicable to models with local
+    latent variables (see :class:`AutoSemiDAIS`), but unlike :class:`AutoDAIS`, it
+    *can* be used in conjunction with data subsampling.
+
+    **Reference:**
+
+    1. *Surrogate likelihoods for variational annealed importance sampling*,
+       Martin Jankowiak, Du Phan
+    2. *MCMC Variational Inference via Uncorrected Hamiltonian Annealing*,
+       Tomas Geffner, Justin Domke
+    3. *Differentiable Annealed Importance Sampling and the Perils of Gradient Noise*,
+       Guodong Zhang, Kyle Hsu, Jianing Li, Chelsea Finn, Roger Grosse
+
+    Usage::
+
+        # logistic regression model for data {X, Y}
+        def model(X, Y):
+            theta = numpyro.sample(
+                "theta", dist.Normal(jnp.zeros(2), jnp.ones(2)).to_event(1)
+            )
+            with numpyro.plate("N", 100, subsample_size=10):
+                X_batch = numpyro.subsample(X, event_dim=1)
+                Y_batch = numpyro.subsample(Y, event_dim=0)
+                numpyro.sample("obs", dist.Bernoulli(logits=theta @ X_batch.T), obs=Y_batch)
+
+        # surrogate model defined by prior and surrogate likelihood.
+        # a convenient choice for specifying the latter is to compute the likelihood on
+        # a randomly chosen data subset (here {X_surr, Y_surr} of size 20) and then use
+        # handlers.scale to scale the log likelihood by a vector of learnable weights.
+        def surrogate_model(X_surr, Y_surr):
+            theta = numpyro.sample(
+                "theta", dist.Normal(jnp.zeros(2), jnp.ones(2)).to_event(1)
+            )
+            omegas = numpyro.param(
+                "omegas", 5.0 * jnp.ones(20), constraint=dist.constraints.positive
+            )
+            with numpyro.plate("N", 20), numpyro.handlers.scale(scale=omegas):
+                numpyro.sample("obs", dist.Bernoulli(logits=theta @ X_surr.T), obs=Y_surr)
+
+        guide = AutoSurrogateLikelihoodDAIS(model, surrogate_model)
+        svi = SVI(model, guide, ...)
+
+    :param callable model: A NumPyro model.
+    :param callable surrogate_model: A NumPyro model that is used as a surrogate model
+        for guiding the HMC dynamics that define the variational distribution. In particular
+        `surrogate_model` should contain the same prior as `model` but should contain a
+        cheap-to-evaluate parametric ansatz for the likelihood. A simple ansatz for the latter
+        involves computing the likelihood for a fixed subset of the data and scaling the resulting
+        log likelihood by a learnable vector of positive weights. See the usage example above.
+    :param str prefix: A prefix that will be prefixed to all param internal sites.
+    :param int K: A positive integer that controls the number of HMC steps used.
+        Defaults to 4.
+    :param str base_dist: Controls whether the base Normal variational distribution
+       is parameterized by a "diagonal" covariance matrix or a full-rank covariance
+       matrix parameterized by a lower-triangular "cholesky" factor. Defaults to "diagonal".
+    :param float eta_init: The initial value of the step size used in HMC. Defaults
+        to 0.01.
+    :param float eta_max: The maximum value of the learnable step size used in HMC.
+        Defaults to 0.1.
+    :param float gamma_init: The initial value of the learnable damping factor used
+        during partial momentum refreshments in HMC. Defaults to 0.9.
+    :param callable init_loc_fn: A per-site initialization function.
+        See :ref:`init_strategy` section for available functions.
+    :param float init_scale: Initial scale for the standard deviation of
+        the base variational distribution for each (unconstrained transformed)
+        latent variable. Defaults to 0.1.
+    """
+
+    def __init__(
+        self,
+        model,
+        surrogate_model,
+        *,
+        K=4,
+        eta_init=0.01,
+        eta_max=0.1,
+        gamma_init=0.9,
+        prefix="auto",
+        base_dist="diagonal",
+        init_loc_fn=init_to_uniform,
+        init_scale=0.1,
+    ):
+        super().__init__(
+            model,
+            K=K,
+            eta_init=eta_init,
+            eta_max=eta_max,
+            gamma_init=gamma_init,
+            prefix=prefix,
+            init_loc_fn=init_loc_fn,
+            init_scale=init_scale,
+            base_dist=base_dist,
+        )
+
+        self.surrogate_model = surrogate_model
+
+    def _setup_prototype(self, *args, **kwargs):
+        AutoContinuous._setup_prototype(self, *args, **kwargs)
+
+        rng_key = numpyro.prng_key()
+
+        with numpyro.handlers.block():
+            (_, self._surrogate_potential_fn, _, _) = initialize_model(
+                rng_key,
+                self.surrogate_model,
+                init_strategy=self.init_loc_fn,
+                dynamic_args=False,
+                model_args=(),
+                model_kwargs={},
+            )
+
+    def _sample_latent(self, *args, **kwargs):
+        def blocked_surrogate_model(x):
+            x_unpack = self._unpack_latent(x)
+            with numpyro.handlers.block(expose_types=["param"]):
+                return -self._surrogate_potential_fn(x_unpack)
+
+        eta0 = numpyro.param(
+            "{}_eta0".format(self.prefix),
+            self.eta_init,
+            constraint=constraints.interval(0, self.eta_max),
+        )
+        eta_coeff = numpyro.param("{}_eta_coeff".format(self.prefix), 0.0)
+
+        gamma = numpyro.param(
+            "{}_gamma".format(self.prefix),
+            self.gamma_init,
+            constraint=constraints.interval(0, 1),
+        )
+        betas = numpyro.param(
+            "{}_beta_increments".format(self.prefix),
+            jnp.ones(self.K),
+            constraint=constraints.positive,
+        )
+        betas = jnp.cumsum(betas)
+        betas = betas / betas[-1]  # K-dimensional with betas[-1] = 1
+
+        mass_matrix = numpyro.param(
+            "{}_mass_matrix".format(self.prefix),
+            jnp.ones(self.latent_dim),
+            constraint=constraints.positive,
+        )
+        inv_mass_matrix = 0.5 / mass_matrix
+
+        init_z_loc = numpyro.param("{}_z_0_loc".format(self.prefix), self._init_latent)
+
+        if self.base_dist == "diagonal":
+            init_z_scale = numpyro.param(
+                "{}_z_0_scale".format(self.prefix),
+                jnp.full(self.latent_dim, self._init_scale),
+                constraint=constraints.positive,
+            )
+            base_z_dist = dist.Normal(init_z_loc, init_z_scale).to_event()
+        else:
+            scale_tril = numpyro.param(
+                "{}_scale_tril".format(self.prefix),
+                jnp.identity(self.latent_dim) * self._init_scale,
+                constraint=constraints.scaled_unit_lower_cholesky,
+            )
+            base_z_dist = dist.MultivariateNormal(init_z_loc, scale_tril=scale_tril)
+
+        z_0 = numpyro.sample(
+            "{}_z_0".format(self.prefix), base_z_dist, infer={"is_auxiliary": True}
+        )
+
+        base_z_dist_log_prob = base_z_dist.log_prob
+
+        momentum_dist = dist.Normal(0, mass_matrix).to_event()
+        eps = numpyro.sample(
+            "{}_momentum".format(self.prefix),
+            momentum_dist.expand((self.K,)).to_event().mask(False),
+            infer={"is_auxiliary": True},
+        )
+
+        def scan_body(carry, eps_beta):
+            eps, beta = eps_beta
+            eta = eta0 + eta_coeff * beta
+            eta = jnp.clip(eta, a_min=0.0, a_max=self.eta_max)
+            z_prev, v_prev, log_factor = carry
+            z_half = z_prev + v_prev * eta * inv_mass_matrix
+            q_grad = (1.0 - beta) * grad(base_z_dist_log_prob)(z_half)
+            p_grad = beta * grad(blocked_surrogate_model)(z_half)
+            v_hat = v_prev + eta * (q_grad + p_grad)
+            z = z_half + v_hat * eta * inv_mass_matrix
+            v = gamma * v_hat + jnp.sqrt(1 - gamma**2) * eps
+            delta_ke = momentum_dist.log_prob(v_prev) - momentum_dist.log_prob(v_hat)
+            log_factor = log_factor + delta_ke
+            return (z, v, log_factor), None
+
+        v_0 = eps[-1]  # note the return value of scan doesn't depend on eps[-1]
+        (z, _, log_factor), _ = jax.lax.scan(scan_body, (z_0, v_0, 0.0), (eps, betas))
+
+        numpyro.factor("{}_factor".format(self.prefix), log_factor)
+
+        return z
+
+
+def _subsample_model(model, *args, **kwargs):
+    data = kwargs.pop("_subsample_idx", {})
+    with handlers.substitute(data=data):
+        return model(*args, **kwargs)
+
+
+class AutoSemiDAIS(AutoGuide):
+    r"""
+    This implementation of :class:`AutoSemiDAIS` [1] combines a parametric
+    variational distribution over global latent variables with Differentiable
+    Annealed Importance Sampling (DAIS) [2, 3] to infer local latent variables.
+    Unlike :class:`AutoDAIS` this guide can be used in conjunction with data subsampling.
+    Note that the resulting ELBO can be understood as a particular realization of a
+    'locally enhanced bound' as described in reference [4].
+
+    **References:**
+
+    1. *Surrogate Likelihoods for Variational Annealed Importance Sampling*,
+       Martin Jankowiak, Du Phan
+    2. *MCMC Variational Inference via Uncorrected Hamiltonian Annealing*,
+       Tomas Geffner, Justin Domke
+    3. *Differentiable Annealed Importance Sampling and the Perils of Gradient Noise*,
+       Guodong Zhang, Kyle Hsu, Jianing Li, Chelsea Finn, Roger Grosse
+    4. *Variational Inference with Locally Enhanced Bounds for Hierarchical Models*,
+       Tomas Geffner, Justin Domke
+
+    Usage::
+
+        def global_model():
+            return numpyro.sample("theta", dist.Normal(0, 1))
+
+        def local_model(theta):
+            with numpyro.plate("data", 8, subsample_size=2):
+                tau = numpyro.sample("tau", dist.Gamma(5.0, 5.0))
+                numpyro.sample("obs", dist.Normal(0.0, tau), obs=jnp.ones(2))
+
+        model = lambda: local_model(global_model())
+        base_guide = AutoNormal(global_model)
+        guide = AutoSemiDAIS(model, local_model, base_guide, K=4)
+        svi = SVI(model, guide, ...)
+
+        # sample posterior for particular data subset {3, 7}
+        with handlers.substitute(data={"data": jnp.array([3, 7])}):
+            samples = guide.sample_posterior(random.PRNGKey(1), params)
+
+    :param callable model: A NumPyro model with global and local latent variables.
+    :param callable local_model: The portion of `model` that includes the local latent variables only.
+        The signature of `local_model` should be the return type of the global model with global latent
+        variables only.
+    :param callable base_guide: A guide for the global latent variables, e.g. an autoguide.
+        The return type should be a dictionary of latent sample sites names and corresponding samples.
+    :param str prefix: A prefix that will be prefixed to all internal sites.
+    :param int K: A positive integer that controls the number of HMC steps used.
+        Defaults to 4.
+    :param float eta_init: The initial value of the step size used in HMC. Defaults
+        to 0.01.
+    :param float eta_max: The maximum value of the learnable step size used in HMC.
+        Defaults to 0.1.
+    :param float gamma_init: The initial value of the learnable damping factor used
+        during partial momentum refreshments in HMC. Defaults to 0.9.
+    :param float init_scale: Initial scale for the standard deviation of the variational
+        distribution for each (unconstrained transformed) local latent variable. Defaults to 0.1.
+    """
+
+    def __init__(
+        self,
+        model,
+        local_model,
+        base_guide,
+        *,
+        prefix="auto",
+        K=4,
+        eta_init=0.01,
+        eta_max=0.1,
+        gamma_init=0.9,
+        init_scale=0.1,
+    ):
+        # init_loc_fn is only used to inspect the model.
+        super().__init__(model, prefix=prefix, init_loc_fn=init_to_uniform)
+        if K < 1:
+            raise ValueError("K must satisfy K >= 1 (got K = {})".format(K))
+        if eta_init <= 0.0 or eta_init >= eta_max:
+            raise ValueError(
+                "eta_init must be positive and satisfy eta_init < eta_max."
+            )
+        if eta_max <= 0.0:
+            raise ValueError("eta_max must be positive.")
+        if gamma_init <= 0.0 or gamma_init >= 1.0:
+            raise ValueError("gamma_init must be in the open interval (0, 1).")
+        if init_scale <= 0.0:
+            raise ValueError("init_scale must be positive.")
+
+        self.local_model = local_model
+        self.base_guide = base_guide
+        self.eta_init = eta_init
+        self.eta_max = eta_max
+        self.gamma_init = gamma_init
+        self.K = K
+        self.init_scale = init_scale
+
+    def _setup_prototype(self, *args, **kwargs):
+        super()._setup_prototype(*args, **kwargs)
+        # extract global/local/local_dim/plates
+        subsample_plates = {
+            name: site
+            for name, site in self.prototype_trace.items()
+            if site["type"] == "plate"
+            and isinstance(site["args"][1], int)
+            and site["args"][0] > site["args"][1]
+        }
+        num_plates = len(subsample_plates)
+        assert (
+            num_plates == 1
+        ), f"AutoSemiDAIS assumes that the model contains exactly 1 plate with data subsampling but got {num_plates}."
+        plate_name = list(subsample_plates.keys())[0]
+        local_vars = []
+        subsample_axes = {}
+        plate_dim = None
+        for name, site in self.prototype_trace.items():
+            if site["type"] == "sample" and not site["is_observed"]:
+                for frame in site["cond_indep_stack"]:
+                    if frame.name == plate_name:
+                        if plate_dim is None:
+                            plate_dim = frame.dim
+                        local_vars.append(name)
+                        subsample_axes[name] = plate_dim - site["fn"].event_dim
+                        break
+        if len(local_vars) == 0:
+            raise RuntimeError(
+                "There are no local variables in the `{plate_name}` plate."
+                " AutoSemiDAIS is appropriate for models with local variables."
+            )
+
+        local_init_locs = {
+            name: value for name, value in self._init_locs.items() if name in local_vars
+        }
+
+        one_sample = {
+            k: jnp.take(v, 0, axis=subsample_axes[k])
+            for k, v in local_init_locs.items()
+        }
+        _, shape_dict = _ravel_dict(one_sample)
+        local_init_latent = jax.vmap(
+            lambda x: _ravel_dict(x)[0], in_axes=(subsample_axes,)
+        )(local_init_locs)
+        unpack_latent = partial(_unravel_dict, shape_dict=shape_dict)
+        # this is to match the behavior of Pyro, where we can apply
+        # unpack_latent for a batch of samples
+        self._unpack_local_latent = jax.vmap(
+            UnpackTransform(unpack_latent), out_axes=subsample_axes
+        )
+        plate_full_size, plate_subsample_size = subsample_plates[plate_name]["args"]
+        self._local_latent_dim = jnp.size(local_init_latent) // plate_subsample_size
+        self._local_plate = (plate_name, plate_full_size, plate_subsample_size)
+
+        rng_key = numpyro.prng_key()
+        with handlers.block(), handlers.seed(rng_seed=rng_key):
+            global_output = self.base_guide.model(*args, **kwargs)
+            (
+                _,
+                self._local_potential_fn_gen,
+                self._local_postprecess_fn,
+                _,
+            ) = initialize_model(
+                numpyro.prng_key(),
+                partial(_subsample_model, self.local_model),
+                init_strategy=self.init_loc_fn,
+                dynamic_args=True,
+                model_args=(global_output,),
+                model_kwargs={
+                    "_subsample_idx": {
+                        plate_name: subsample_plates[plate_name]["value"]
+                    }
+                },
+            )
+
+    def __call__(self, *args, **kwargs):
+        if self.prototype_trace is None:
+            # run model to inspect the model structure
+            self._setup_prototype(*args, **kwargs)
+
+        global_latents, local_latent_flat = self._sample_latent(*args, **kwargs)
+
+        # unpack continuous latent samples
+        result = global_latents.copy()
+        _, N, subsample_size = self._local_plate
+
+        for name, unconstrained_value in self._unpack_local_latent(
+            local_latent_flat
+        ).items():
+            site = self.prototype_trace[name]
+            with helpful_support_errors(site):
+                transform = biject_to(site["fn"].support)
+            value = transform(unconstrained_value)
+            event_ndim = site["fn"].event_dim
+            if numpyro.get_mask() is False:
+                log_density = 0.0
+            else:
+                log_density = -transform.log_abs_det_jacobian(
+                    unconstrained_value, value
+                )
+                log_density = (N / subsample_size) * sum_rightmost(
+                    log_density, jnp.ndim(log_density) - jnp.ndim(value) + event_ndim
+                )
+            delta_dist = dist.Delta(
+                value, log_density=log_density, event_dim=event_ndim
+            )
+            result[name] = numpyro.sample(name, delta_dist)
+
+        return result
+
+    def _get_posterior(self):
+        raise NotImplementedError
+
+    def _sample_latent(self, *args, **kwargs):
+        kwargs.pop("sample_shape", ())
+
+        def make_local_log_density(*local_args, **local_kwargs):
+            def fn(x):
+                x_unpack = self._unpack_local_latent(x)
+                with numpyro.handlers.block():
+                    return -self._local_potential_fn_gen(*local_args, **local_kwargs)(
+                        x_unpack
+                    )
+
+            return fn
+
+        global_latents = self.base_guide(*args, **kwargs)
+        rng_key = numpyro.prng_key()
+        with handlers.block(), handlers.seed(rng_seed=rng_key), handlers.substitute(
+            data=global_latents
+        ):
+            global_output = self.base_guide.model(*args, **kwargs)
+
+        plate_name, N, subsample_size = self._local_plate
+        D, K = self._local_latent_dim, self.K
+
+        with numpyro.plate(plate_name, N, subsample_size=subsample_size) as idx:
+            eta0 = numpyro.param(
+                "{}_eta0".format(self.prefix),
+                jnp.ones(N) * self.eta_init,
+                constraint=constraints.interval(0, self.eta_max),
+                event_dim=0,
+            )
+            eta_coeff = numpyro.param(
+                "{}_eta_coeff".format(self.prefix), jnp.zeros(N), event_dim=0
+            )
+
+            gamma = numpyro.param(
+                "{}_gamma".format(self.prefix),
+                jnp.ones(N) * 0.9,
+                constraint=constraints.interval(0, 1),
+                event_dim=0,
+            )
+            betas = numpyro.param(
+                "{}_beta_increments".format(self.prefix),
+                jnp.ones((N, K)),
+                constraint=constraints.positive,
+                event_dim=1,
+            )
+            betas = jnp.cumsum(betas, axis=-1)
+            betas = betas / betas[..., -1:]
+
+            mass_matrix = numpyro.param(
+                "{}_mass_matrix".format(self.prefix),
+                jnp.ones((N, D)),
+                constraint=constraints.positive,
+                event_dim=1,
+            )
+            inv_mass_matrix = 0.5 / mass_matrix
+            assert inv_mass_matrix.shape == (subsample_size, D)
+            z_0_loc_init = jnp.zeros((N, D))
+            z_0_loc = numpyro.param(
+                "{}_z_0_loc".format(self.prefix), z_0_loc_init, event_dim=1
+            )
+            z_0_scale_init = jnp.ones((N, D)) * self.init_scale
+            z_0_scale = numpyro.param(
+                "{}_z_0_scale".format(self.prefix),
+                z_0_scale_init,
+                constraint=constraints.positive,
+                event_dim=1,
+            )
+            base_z_dist = dist.Normal(z_0_loc, z_0_scale).to_event(1)
+            assert base_z_dist.shape() == (subsample_size, D)
+            z_0 = numpyro.sample(
+                "{}_z_0".format(self.prefix), base_z_dist, infer={"is_auxiliary": True}
+            )
+
+            def base_z_dist_log_prob(x):
+                return base_z_dist.log_prob(x).sum()
+
+            momentum_dist = dist.Normal(0, mass_matrix).to_event(1)
+            eps = numpyro.sample(
+                "{}_momentum".format(self.prefix),
+                dist.Normal(0, mass_matrix[..., None])
+                .expand([subsample_size, D, K])
+                .to_event(2)
+                .mask(False),
+                infer={"is_auxiliary": True},
+            )
+
+            local_log_density = make_local_log_density(
+                global_output, _subsample_idx={plate_name: idx}
+            )
+
+            def scan_body(carry, eps_beta):
+                eps, beta = eps_beta
+                eta = eta0 + eta_coeff * beta
+                eta = jnp.clip(eta, a_min=0.0, a_max=self.eta_max)
+                assert eps.shape == (subsample_size, D)
+                assert eta.shape == beta.shape == (subsample_size,)
+                z_prev, v_prev, log_factor = carry
+                z_half = z_prev + v_prev * eta[:, None] * inv_mass_matrix
+                q_grad = (1.0 - beta[:, None]) * grad(base_z_dist_log_prob)(z_half)
+                p_grad = (
+                    beta[:, None]
+                    * (subsample_size / N)
+                    * grad(local_log_density)(z_half)
+                )
+                assert q_grad.shape == p_grad.shape == (subsample_size, D)
+                v_hat = v_prev + eta[:, None] * (q_grad + p_grad)
+                z = z_half + v_hat * eta[:, None] * inv_mass_matrix
+                v = gamma[:, None] * v_hat + jnp.sqrt(1 - gamma[:, None] ** 2) * eps
+                delta_ke = momentum_dist.log_prob(v_prev) - momentum_dist.log_prob(
+                    v_hat
+                )
+                assert delta_ke.shape == (subsample_size,)
+                log_factor = log_factor + delta_ke
+                return (z, v, log_factor), None
+
+            v_0 = eps[
+                :, :, -1
+            ]  # note the return value of scan doesn't depend on eps[:, :, -1]
+            assert eps.shape == (subsample_size, D, K)
+            assert betas.shape == (subsample_size, K)
+
+            eps_T = jnp.moveaxis(eps, -1, 0)
+            (z, _, log_factor), _ = jax.lax.scan(
+                scan_body, (z_0, v_0, jnp.zeros(subsample_size)), (eps_T, betas.T)
+            )
+            assert log_factor.shape == (subsample_size,)
+
+            numpyro.factor("{}_local_dais_factor".format(self.prefix), log_factor)
+            return global_latents, z
+
+    def sample_posterior(self, rng_key, params, *args, sample_shape=(), **kwargs):
+        def _single_sample(_rng_key):
+            global_latents, local_flat = handlers.substitute(
+                handlers.seed(self._sample_latent, _rng_key), params
+            )(*args, **kwargs)
+            results = global_latents.copy()
+            for name, unconstrained_value in self._unpack_local_latent(
+                local_flat
+            ).items():
+                site = self.prototype_trace[name]
+                transform = biject_to(site["fn"].support)
+                value = transform(unconstrained_value)
+                results[name] = value
+            return results
+
+        if sample_shape:
+            rng_key = random.split(rng_key, int(np.prod(sample_shape)))
+            samples = lax.map(_single_sample, rng_key)
+            return tree_map(
+                lambda x: jnp.reshape(x, sample_shape + jnp.shape(x)[1:]),
+                samples,
+            )
+        else:
+            return _single_sample(rng_key)
+
+
 class AutoDiagonalNormal(AutoContinuous):
     """
     This implementation of :class:`AutoContinuous` uses a Normal distribution
@@ -974,7 +1549,7 @@ class AutoMultivariateNormal(AutoContinuous):
         Returns a multivariate Normal posterior distribution.
         """
         transform = self.get_transform(params)
-        return dist.MultivariateNormal(transform.loc, transform.scale_tril)
+        return dist.MultivariateNormal(transform.loc, scale_tril=transform.scale_tril)
 
     def median(self, params):
         loc = params["{}_loc".format(self.prefix)]
