@@ -209,7 +209,10 @@ def _unconstrain_reparam(params, site):
             if jnp.ndim(p) > expected_unconstrained_dim:
                 p = p[i]
 
-        if support in [constraints.real, constraints.real_vector]:
+        if support is constraints.real or (
+            isinstance(support, constraints.independent)
+            and support.base_constraint is constraints.real
+        ):
             return p
         value = t(p)
 
